@@ -11,8 +11,8 @@
 #' @param url Link to a ZIP file containing the materials. To reduce the chance
 #'   of typos in live settings, these shorter forms are accepted:
 #'
-#'     * GitHub repo spec: "OWNER/REPO". Auto-expands to
-#'       `https://github.com/r-lib/OWNER/REPO/master.zip`.
+#'     * GitHub repo spec: "OWNER/REPO". Equivalent to
+#'       `https://github.com/OWNER/REPO/DEFAULT_BRANCH.zip`.
 #'     * bit.ly or rstd.io shortlinks: "bit.ly/xxx-yyy-zzz" or "rstd.io/foofy".
 #'       The instructor must then arrange for the shortlink to point to a valid
 #'       download URL for the target ZIP file. The helper
@@ -38,10 +38,11 @@
 #' # download the source of rematch2 package from CRAN
 #' use_course("https://cran.r-project.org/bin/windows/contrib/3.4/rematch2_2.0.1.zip")
 #'
-#' # download the source of rematch2 package from GitHub, 3 ways
+#' # download the source of rematch2 package from GitHub, 4 ways
 #' use_course("r-lib/rematch2")
-#' use_course("https://github.com/r-lib/rematch2/archive/master.zip")
+#' use_course("https://api.github.com/repos/r-lib/rematch2/zipball/HEAD")
 #' use_course("https://api.github.com/repos/r-lib/rematch2/zipball/master")
+#' use_course("https://github.com/r-lib/rematch2/archive/master.zip")
 #' }
 NULL
 
@@ -164,10 +165,14 @@ use_zip <- function(url,
 #' ```
 #' This download link (or a shortlink that points to it) is suitable as input
 #' for `tidy_download()`. After one or more redirections, this link will
-#' eventually lead to a download URL. Here's an alternative link that also leads
-#' to ZIP download, albeit with a different filenaming scheme:
+#' eventually lead to a download URL. Here are other links that also lead to
+#' ZIP download, albeit with a different filenaming scheme (REF could be a
+#' branch name, a tag, or a SHA):
 #' ```
-#' https://api.github.com/repos/r-lib/usethis/zipball/master
+#' https://github.com/github.com/r-lib/usethis/zipball/HEAD
+#' https://api.github.com/repos/r-lib/rematch2/zipball/REF
+#' https://api.github.com/repos/r-lib/rematch2/zipball/HEAD
+#' https://api.github.com/repos/r-lib/usethis/zipball/REF
 #' ```
 #'
 #' You can use `create_download_url()` to create the "Download ZIP" URL from
@@ -312,7 +317,8 @@ download_url <- function(url,
     if (i == 1) {
       curl::handle_setopt(
         handle,
-        .list = c(connecttimeout = retry_connecttimeout))
+        .list = c(connecttimeout = retry_connecttimeout)
+      )
     }
     i <- i + 1
     ui_info("Retrying download ... attempt {i}")
@@ -357,8 +363,8 @@ tidy_unzip <- function(zipfile, cleanup = FALSE) {
     target <- path_ext_remove(zipfile)
     utils::unzip(zipfile, files = filenames, exdir = target)
   } else {
-    target <- path(path_dir(zipfile), td)
-    utils::unzip(zipfile, files = filenames, exdir = path_dir(zipfile))
+    target <- path(base_path, td)
+    utils::unzip(zipfile, files = filenames, exdir = base_path)
   }
   ui_done(
     "Unpacking ZIP file into {ui_path(target, base_path)} \\
@@ -437,7 +443,7 @@ modify_drive_url <- function(url) {
     return(hopeless_url(url))
   }
   id <- gsub("/d/|/folders/|id=", "", regmatches(url, id_loc))
-  glue("https://drive.google.com/uc?export=download&id={id}")
+  glue_chr("https://drive.google.com/uc?export=download&id={id}")
 }
 
 modify_dropbox_url <- function(url) {
@@ -445,8 +451,14 @@ modify_dropbox_url <- function(url) {
 }
 
 modify_github_url <- function(url) {
-  df <- rematch2::re_match(url, github_url_rx())
-  glue("https://github.com/{df$owner}/{df$repo}/archive/master.zip")
+  # TO CONSIDER: one could use the API for this, which might be more proper and
+  # would work if auth is needed
+  # https://docs.github.com/en/free-pro-team@latest/rest/reference/repos#download-a-repository-archive-zip
+  # https://api.github.com/repos/OWNER/REPO/zipball/
+  # but then, in big workshop settings, we might see rate limit problems or
+  # get blocked because of too many token-free requests from same IP
+  parsed <- parse_github_remotes(url)
+  glue_data_chr(parsed, "{protocol}://{host}/{repo_owner}/{repo_name}/zipball/HEAD")
 }
 
 hopeless_url <- function(url) {
@@ -477,18 +489,20 @@ normalize_url <- function(url) {
 
 is_shortlink <- function(url) {
   shortlink_hosts <- c("rstd\\.io", "bit\\.ly")
-  any(purrr::map_lgl(shortlink_hosts, grepl, x = url))
+  any(map_lgl(shortlink_hosts, grepl, x = url))
 }
 
 expand_github <- function(url) {
   # mostly to handle errors in the spec
   repo_spec <- parse_repo_spec(url)
-  glue::glue_data(repo_spec, "github.com/{owner}/{repo}/archive/master.zip")
+  glue_data_chr(repo_spec, "github.com/{owner}/{repo}/zipball/HEAD")
 }
 
 conspicuous_place <- function() {
   destdir_opt <- getOption("usethis.destdir")
-  if (!is.null(destdir_opt)) return(path_tidy(destdir_opt))
+  if (!is.null(destdir_opt)) {
+    return(path_tidy(destdir_opt))
+  }
 
   Filter(dir_exists, c(
     path_home("Desktop"),
@@ -508,7 +522,7 @@ keep_lgl <- function(file,
 }
 
 top_directory <- function(filenames) {
-  in_top <- dirname(filenames) == "."
+  in_top <- path_dir(filenames) == "."
   unique_top <- unique(filenames[in_top])
   is_directory <- grepl("/$", unique_top)
   if (length(unique_top) > 1 || !is_directory) {
@@ -586,7 +600,7 @@ progress_fun <- function(down, up) {
 make_filename <- function(cd,
                           fallback = path_file(file_temp())) {
   ## TO DO(jennybc): the element named 'filename*' is preferred but I'm not
-  ## sure how to parse it yet, so targetting 'filename' for now
+  ## sure how to parse it yet, so targeting 'filename' for now
   ## https://tools.ietf.org/html/rfc6266
   cd <- cd[["filename"]]
   if (is.null(cd) || is.na(cd)) {
